@@ -1,22 +1,55 @@
 /* Javascript functions for the lizard user interface */
 
-// jslint configuration
+// jslint configuration.  Don't put spaces before 'jslint' and 'global'.
 /*jslint browser: true */
 /*global $, OpenLayers, window */
 
-// Globals that we define
-var mainContentHeight, sidebarHeight, mainContentWidth, verticalItemHeight,
-    accordion;
+// Globals that we ourselves define.
+var hiddenStuffHeight, mainContentHeight, sidebarHeight, mainContentWidth,
+    verticalItemHeight, accordion, resizeTimer;
 
 
 function reloadGraphs() {
-    // Overridden in krw-waternet...
-    //loadCorrectlySizedImages();
+    $('a.replace-with-image').each(
+        function (index) {
+            var url, timestamp, width, height, amp_or_questionmark;
+            width = $(this).parent('.img-use-my-width').innerWidth();
+            height = $(this).parent('.img-use-my-height').innerHeight();
+            if (width === null) {
+                width = '';
+            }
+            if (height === null) {
+                height = '';
+            }
+            $(this).hide();
+            url = $(this).attr('href');
+            if (url.indexOf('?')) {
+                amp_or_questionmark = '&';
+            } else {
+                amp_or_questionmark = '?';
+            }
+            // Remove a previous image that's already there.
+            $('~ img', this).remove();
+            timestamp = new Date().getTime();  // No cached images.
+            $(this).after('<img src="' + url +
+                          amp_or_questionmark +
+                          'width=' + width +
+                          '&height=' + height +
+                          '&random=' + timestamp + '" ' +
+                          'width="' + width + '" ' +
+                          'height="' + height + '" ' +
+                          '/>');
+        }
+    );
 }
 
+function calculateHiddenStuffHeight() {
+    // Calculate once.  If opened, the height isn't 5 but 208 or so...
+    hiddenStuffHeight = $("#ui-datepicker-div").outerHeight(true);
+}
 
 function stretchOneSidebarBox() {
-    /* Stretch out one sidebarbox so that the sidebar is completely filled */
+    /* Stretch out one sidebarbox so that the sidebar is completely filled. */
     var stillAvailable, includeMargin;
     $("#sidebar .sidebarbox-stretched").height('0');
     stillAvailable = $("#sidebar").innerHeight();
@@ -43,7 +76,7 @@ function fillScreen() {
 
     The resulting height is available as "mainContentHeight".  */
 
-    var jqueryBug, viewportHeight, bottomMargin, headerHeight,
+    var viewportHeight, bottomMargin, headerHeight,
         stuffAroundSidebar, footerHeight, menubarHeight,
         stuffAroundMainContent, mainAreaWidth, sidebarWidth, collapserWidth,
         mainDivWidth, viewportWidth;
@@ -57,9 +90,9 @@ function fillScreen() {
     // ^^^ 2px border for the content.
     $("#main").width(mainDivWidth);
     mainContentWidth = $("#content").innerWidth();
+
     // Height.
-    jqueryBug = $("#ui-datepicker-div").outerHeight(true);
-    viewportHeight = $(window).height() - jqueryBug;
+    viewportHeight = $(window).height() - hiddenStuffHeight;
     bottomMargin = $("#page").outerHeight(true) - $("#page").innerHeight();
     headerHeight = $("#header").outerHeight(true);
     stuffAroundSidebar = $("#sidebar").outerHeight(true) -
@@ -198,7 +231,6 @@ function setUpScreen() {
 */
 $(window).resize(function () {
     // Don't re-calculate 50 times while resizing, only when finished.
-    var resizeTimer;
     if (resizeTimer) {
         clearTimeout(resizeTimer);
     }
@@ -207,15 +239,20 @@ $(window).resize(function () {
             fillScreen();
             divideVerticalSpaceEqually();
             stretchOneSidebarBox();
+            reloadGraphs();
         },
-        600);
+        300);
 });
 
 
-$(document).ready(fillScreen);
-$(document).ready(divideVerticalSpaceEqually);
-$(document).ready(setUpCollapsibleSidebarBoxes);
-$(document).ready(setUpCollapsibleSidebar);
-$(document).ready(setUpAccordion);
-$(document).ready(setUpTree);
-$(document).ready(stretchOneSidebarBox);
+$(document).ready(function () {
+    calculateHiddenStuffHeight();
+    fillScreen();
+    divideVerticalSpaceEqually();
+    setUpCollapsibleSidebarBoxes();
+    setUpCollapsibleSidebar();
+    setUpAccordion();
+    setUpTree();
+    stretchOneSidebarBox();
+    reloadGraphs();
+});
